=============================================
Acknowledgments, Contributors, and References
=============================================

Acknowledgments
===============

We would like to thank the contributors and maintainers of the open-source projects that we depend on. Your hard work and dedication make this project possible.

Contributors
============

Thanks to our contributors!

..  contributors:: amal-khailtash/pyipxact-de
   :avatars:
   :limit: 100
   :order: DESC

References
==========

* `SPIRIT Consortium: <https://www.spiritconsortium.org/>`_
* `Accellera <https://accellera.org/>`_
    * `Accellera IP-XACT Standard: <https://www.accellera.org/downloads/standards/ipxact>`_
    * `IP-XACT Working Group <https://accellera.org/activities/working-groups/ip-xact>`_
    * `IP-XACT Downloads <https://accellera.org/downloads/standards/ip-xact>`_
    * `IP-XACT User Guide <https://accellera.org/images/downloads/standards/ip-xact/IPXACT-2022_user_guide.pdf>`_
    * `XML Schemas <http://www.accellera.org/XMLSchema>`_
    * `Leon2 examples <https://accellera.org/images/activities/committees/ip-xact/Leon2_1685-2022.zip>`_
    * `Conversion scripts <https://www.accellera.org/images/downloads/standards/ip-xact/update_scripts_9-13-2024.zip>`_
* `Accellera SPIRIT/IP-XACT XML Schemas (github copy) <https://github.com/amal-khailtash/accellera-schemas>`_
